@@ -5,7 +5,7 @@ use Kavorka -all;
 use utf8;
 use Telugu::TGC;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 has 'tgc' => (
@@ -18,7 +18,7 @@ has 'tgc' => (
 );
 
 
-method ngram( $string, $n ) {
+method ngram( Str $string, Int $n ) {
 	my @filtered  = $self->tgc->TGC($string);
 
     my @ngram;
@@ -46,7 +46,7 @@ Telugu::Utils - Utilities for Telugu strings.
   binmode STDOUT, ":encoding(UTF-8)";
 
   my $util = Telugu::Utils->new();
-  my @ngrams = $util->ngram("సర్దార్ జమలాపురం కేశవరావు", 2);
+  my @ngrams = $util->ngram("రాజ్కుమార్రెడ్డి", 2);
   print $ngrams[1][0], "\n";
 
 
